entities/test/unittest_base.py
changeset 1977 606923dff11b
parent 1642 12a98b17fb05
child 2650 18aec79ec3a3
--- a/entities/test/unittest_base.py	Thu May 28 08:06:12 2009 +0200
+++ b/entities/test/unittest_base.py	Thu May 28 09:20:07 2009 +0200
@@ -1,5 +1,11 @@
 # -*- coding: utf-8 -*-
-"""unit tests for cubicweb.entities.base module"""
+"""unit tests for cubicweb.entities.base module
+
+:organization: Logilab
+:copyright: 2001-2009 LOGILAB S.A. (Paris, FRANCE), license is LGPL v2.
+:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
+:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
+"""
 
 from logilab.common.testlib import unittest_main
 from logilab.common.decorators import clear_cache